# generated by 'xml2py'
# flags '-c -d -v C:\test_h\CameraParams.xml -o CameraParams_header.py'
# pylint: skip-file
from ctypes import *

STRING = c_char_p


MV_EXPOSURE_MODE_TRIGGER_WIDTH = 1
MV_TRIGGER_SOURCE_FrequencyConverter = 8
MV_TRIGGER_SOURCE_SOFTWARE = 7
MV_TRIGGER_SOURCE_COUNTER0 = 4
MV_BALANCEWHITE_AUTO_OFF = 0
MV_TRIGGER_SOURCE_LINE3 = 3
MV_TRIGGER_SOURCE_LINE2 = 2
MV_TRIGGER_SOURCE_LINE1 = 1
MV_EXPOSURE_MODE_TIMED = 0
MV_TRIGGER_SOURCE_LINE0 = 0
AM_NA = 1
PixelType_Gvsp_BayerGR8 = 17301512
PixelType_Gvsp_Mono16 = 17825799
PixelType_Gvsp_Mono14 = 17825829
PixelType_Gvsp_Mono12 = 17825797
PixelType_Gvsp_Mono10 = 17825795
V_Undefined = 99
PixelType_Gvsp_Mono12_Packed = 17563654
V_Invisible = 3
PixelType_Gvsp_Mono8 = 17301505
V_Guru = 2
PixelType_Gvsp_Mono4p = 17039417
V_Expert = 1
PixelType_Gvsp_BayerGR16 = 17825838
PixelType_Gvsp_Mono1p = 16842807
PixelType_Gvsp_Undefined = -1
MV_GAIN_MODE_CONTINUOUS = 2
IFT_IString = 6
PixelType_Gvsp_BayerBG10 = 17825807
MV_ACQ_MODE_CONTINUOUS = 2
MV_EXPOSURE_AUTO_MODE_ONCE = 1
MV_Image_Png = 3
MV_Image_Jpeg = 2
MV_Image_Bmp = 1
MV_ACQ_MODE_MUTLI = 1
MV_EXPOSURE_AUTO_MODE_OFF = 0
PixelType_Gvsp_Jpeg = -2145910783
PixelType_Gvsp_RGB16_Planar = 36700196
IFT_IPort = 11
IFT_IEnumEntry = 10
IFT_ICategory = 8
IFT_IRegister = 7
IFT_IFloat = 5
IFT_IEnumeration = 9
IFT_ICommand = 4
IFT_IBoolean = 3
IFT_IInteger = 2
IFT_IBase = 1
PixelType_Gvsp_COORD3D_DEPTH_PLUS_MASK = -2112094207
IFT_IValue = 0
PixelType_Gvsp_Coord3D_AC32f = 36176066
PixelType_Gvsp_Coord3D_ABC32f_Planar = 39846081
PixelType_Gvsp_Coord3D_ABC32f = 39846080
PixelType_Gvsp_RGB12_Planar = 36700195
PixelType_Gvsp_RGB10_Planar = 36700194
PixelType_Gvsp_YCBCR709_411_8_CBYYCRYY = 34340930
MV_TRIGGER_MODE_OFF = 0
PixelType_Gvsp_YCBCR709_422_8_CBYCRY = 34603077
PixelType_Gvsp_YCBCR709_8_CBYCR = 35127360
PixelType_Gvsp_YCBCR709_422_8 = 34603073
PixelType_Gvsp_YCBCR601_411_8_CBYYCRYY = 34340927
PixelType_Gvsp_YCBCR601_422_8 = 34603070
PixelType_Gvsp_YCBCR601_8_CBYCR = 35127357
MV_TRIGGER_MODE_ON = 1
PixelType_Gvsp_YCBCR411_8_CBYYCRYY = 34340924
PixelType_Gvsp_YCBCR422_8_CBYCRY = 34603075
PixelType_Gvsp_YCBCR422_8 = 34603067
PixelType_Gvsp_YCBCR8_CBYCR = 35127354
PixelType_Gvsp_YUV444_Packed = 35127328
PixelType_Gvsp_YUV422_YUYV_Packed = 34603058
PixelType_Gvsp_YUV422_Packed = 34603039
PixelType_Gvsp_YUV411_Packed = 34340894
PixelType_Gvsp_BGR565_Packed = 34603062
PixelType_Gvsp_RGB565_Packed = 34603061
PixelType_Gvsp_RGB12V1_Packed = 35913780
PixelType_Gvsp_RGB10V2_Packed = 35651613
PixelType_Gvsp_RGB16_Packed = 36700211
PixelType_Gvsp_YCBCR601_422_8_CBYCRY = 34603076
PixelType_Gvsp_RGB12_Packed = 36700186
PixelType_Gvsp_BGR10_Packed = 36700185
MV_GIGE_TRANSTYPE_UNICAST = 0
PixelType_Gvsp_RGB10_Packed = 36700184
PixelType_Gvsp_BGRA8_Packed = 35651607
PixelType_Gvsp_RGBA8_Packed = 35651606
PixelType_Gvsp_BGR8_Packed = 35127317
PixelType_Gvsp_RGB8_Packed = 35127316
PixelType_Gvsp_BayerBG16 = 17825841
PixelType_Gvsp_BayerGB16 = 17825840
PixelType_Gvsp_BayerRG16 = 17825839
PixelType_Gvsp_BayerBG12_Packed = 17563693
PixelType_Gvsp_BayerGB12_Packed = 17563692
PixelType_Gvsp_BayerRG12_Packed = 17563691
PixelType_Gvsp_BayerGR12_Packed = 17563690
PixelType_Gvsp_BayerBG10_Packed = 17563689
PixelType_Gvsp_BayerGB10_Packed = 17563688
MV_GAIN_MODE_ONCE = 1
PixelType_Gvsp_BayerRG10_Packed = 17563687
PixelType_Gvsp_BayerGR10_Packed = 17563686
PixelType_Gvsp_BayerBG12 = 17825811
PixelType_Gvsp_BayerGB12 = 17825810
PixelType_Gvsp_BayerRG12 = 17825809
PixelType_Gvsp_BayerGR12 = 17825808
PixelType_Gvsp_BayerGB10 = 17825806
PixelType_Gvsp_BayerRG10 = 17825805
PixelType_Gvsp_BayerGR10 = 17825804
PixelType_Gvsp_BayerBG8 = 17301515
PixelType_Gvsp_BayerGB8 = 17301514
PixelType_Gvsp_BayerRG8 = 17301513
MV_EXPOSURE_AUTO_MODE_CONTINUOUS = 2
MV_Image_Tif = 4
AM_RW = 4
MV_BALANCEWHITE_AUTO_CONTINUOUS = 1
MV_BALANCEWHITE_AUTO_ONCE = 2
PixelType_Gvsp_Mono2p = 16908344
MV_GAMMA_SELECTOR_SRGB = 2
MV_GAIN_MODE_OFF = 0
PixelType_Gvsp_Mono10_Packed = 17563652
MV_GAMMA_SELECTOR_USER = 1
PixelType_Gvsp_RGB8_Planar = 35127329
PixelType_Gvsp_Mono8_Signed = 17301506
MV_ACQ_MODE_SINGLE = 0
AM_CycleDetect = 6
MV_GIGE_TRANSTYPE_MULTICAST_WITHOUT_RECV = 65537
AM_Undefined = 5
MV_GIGE_TRANSTYPE_UNICAST_WITHOUT_RECV = 65536
MV_GIGE_TRANSTYPE_UNICAST_DEFINED_PORT = 5
AM_RO = 3
MV_GIGE_TRANSTYPE_SUBNETBROADCAST = 3
PixelType_Gvsp_RGB10V1_Packed = 35651612
MV_GIGE_TRANSTYPE_LIMITEDBROADCAST = 2
MV_GIGE_TRANSTYPE_MULTICAST = 1
MV_GIGE_TRANSTYPE_CAMERADEFINED = 4
AM_NI = 0
PixelType_Gvsp_BGR12_Packed = 36700187
MV_Image_Undefined = 0
AM_WO = 2
V_Beginner = 0
int8_t = c_int8
int16_t = c_int16
int32_t = c_int32
int64_t = c_int64
uint8_t = c_uint8
uint16_t = c_uint16
uint32_t = c_uint32
uint64_t = c_uint64
int_least8_t = c_byte
int_least16_t = c_short
int_least32_t = c_int
int_least64_t = c_long
uint_least8_t = c_ubyte
uint_least16_t = c_ushort
uint_least32_t = c_uint
uint_least64_t = c_ulong
int_fast8_t = c_byte
int_fast16_t = c_long
int_fast32_t = c_long
int_fast64_t = c_long
uint_fast8_t = c_ubyte
uint_fast16_t = c_ulong
uint_fast32_t = c_ulong
uint_fast64_t = c_ulong
intptr_t = c_long
uintptr_t = c_ulong
intmax_t = c_long
uintmax_t = c_ulong


# CameraParams.h 21
class _MV_GIGE_DEVICE_INFO_(Structure):
    pass


_MV_GIGE_DEVICE_INFO_._fields_ = [
    # CameraParams.h 21
    ("nIpCfgOption", c_uint),
    ("nIpCfgCurrent", c_uint),
    ("nCurrentIp", c_uint),
    ("nCurrentSubNetMask", c_uint),
    ("nDefultGateWay", c_uint),
    ("chManufacturerName", c_ubyte * 32),
    ("chModelName", c_ubyte * 32),
    ("chDeviceVersion", c_ubyte * 32),
    ("chManufacturerSpecificInfo", c_ubyte * 48),
    ("chSerialNumber", c_ubyte * 16),
    ("chUserDefinedName", c_ubyte * 16),
    ("nNetExport", c_uint),
    ("nReserved", c_uint * 4),
]
MV_GIGE_DEVICE_INFO = _MV_GIGE_DEVICE_INFO_


# CameraParams.h 42
class _MV_USB3_DEVICE_INFO_(Structure):
    pass


_MV_USB3_DEVICE_INFO_._fields_ = [
    # CameraParams.h 42
    ("CrtlInEndPoint", c_ubyte),
    ("CrtlOutEndPoint", c_ubyte),
    ("StreamEndPoint", c_ubyte),
    ("EventEndPoint", c_ubyte),
    ("idVendor", c_ushort),
    ("idProduct", c_ushort),
    ("nDeviceNumber", c_uint),
    ("chDeviceGUID", c_ubyte * 64),
    ("chVendorName", c_ubyte * 64),
    ("chModelName", c_ubyte * 64),
    ("chFamilyName", c_ubyte * 64),
    ("chDeviceVersion", c_ubyte * 64),
    ("chManufacturerName", c_ubyte * 64),
    ("chSerialNumber", c_ubyte * 64),
    ("chUserDefinedName", c_ubyte * 64),
    ("nbcdUSB", c_uint),
    ("nReserved", c_uint * 3),
]
MV_USB3_DEVICE_INFO = _MV_USB3_DEVICE_INFO_


# CameraParams.h 64
class _MV_CC_DEVICE_INFO_(Structure):
    pass


# CameraParams.h 76
class N19_MV_CC_DEVICE_INFO_3DOT_0E(Union):
    pass


N19_MV_CC_DEVICE_INFO_3DOT_0E._fields_ = [
    # CameraParams.h 76
    ("stGigEInfo", MV_GIGE_DEVICE_INFO),
    ("stUsb3VInfo", MV_USB3_DEVICE_INFO),
]
_MV_CC_DEVICE_INFO_._fields_ = [
    # CameraParams.h 64
    ("nMajorVer", c_ushort),
    ("nMinorVer", c_ushort),
    ("nMacAddrHigh", c_uint),
    ("nMacAddrLow", c_uint),
    ("nTLayerType", c_uint),
    ("nReserved", c_uint * 4),
    ("SpecialInfo", N19_MV_CC_DEVICE_INFO_3DOT_0E),
]
MV_CC_DEVICE_INFO = _MV_CC_DEVICE_INFO_


# CameraParams.h 86
class _MV_NETTRANS_INFO_(Structure):
    pass


_MV_NETTRANS_INFO_._fields_ = [
    # CameraParams.h 86
    ("nReviceDataSize", int64_t),
    ("nThrowFrameCount", c_int),
    ("nReserved", c_uint * 5),
]
MV_NETTRANS_INFO = _MV_NETTRANS_INFO_


# CameraParams.h 101
class _MV_CC_DEVICE_INFO_LIST_(Structure):
    pass


_MV_CC_DEVICE_INFO_LIST_._fields_ = [
    # CameraParams.h 101
    ("nDeviceNum", c_uint),
    ("pDeviceInfo", POINTER(MV_CC_DEVICE_INFO) * 256),
]
MV_CC_DEVICE_INFO_LIST = _MV_CC_DEVICE_INFO_LIST_


# CameraParams.h 110
class _MV_FRAME_OUT_INFO_(Structure):
    pass


# values for enumeration 'MvGvspPixelType'
MvGvspPixelType = int64_t  # enum
_MV_FRAME_OUT_INFO_._fields_ = [
    # CameraParams.h 110
    ("nWidth", c_ushort),
    ("nHeight", c_ushort),
    ("enPixelType", MvGvspPixelType),
    ("nFrameNum", c_uint),
    ("nDevTimeStampHigh", c_uint),
    ("nDevTimeStampLow", c_uint),
    ("nReserved0", c_uint),
    ("nHostTimeStamp", int64_t),
    ("nFrameLen", c_uint),
    ("nLostPacket", c_uint),
    ("nReserved", c_uint * 2),
]
MV_FRAME_OUT_INFO = _MV_FRAME_OUT_INFO_


# CameraParams.h 129
class _MV_FRAME_OUT_INFO_EX_(Structure):
    pass


_MV_FRAME_OUT_INFO_EX_._fields_ = [
    # CameraParams.h 129
    ("nWidth", c_ushort),
    ("nHeight", c_ushort),
    ("enPixelType", MvGvspPixelType),
    ("nFrameNum", c_uint),
    ("nDevTimeStampHigh", c_uint),
    ("nDevTimeStampLow", c_uint),
    ("nReserved0", c_uint),
    ("nHostTimeStamp", int64_t),
    ("nFrameLen", c_uint),
    ("nSecondCount", c_uint),
    ("nCycleCount", c_uint),
    ("nCycleOffset", c_uint),
    ("fGain", c_float),
    ("fExposureTime", c_float),
    ("nAverageBrightness", c_uint),
    ("nRed", c_uint),
    ("nGreen", c_uint),
    ("nBlue", c_uint),
    ("nFrameCounter", c_uint),
    ("nTriggerIndex", c_uint),
    ("nInput", c_uint),
    ("nOutput", c_uint),
    ("nOffsetX", c_ushort),
    ("nOffsetY", c_ushort),
    ("nChunkWidth", c_ushort),
    ("nChunkHeight", c_ushort),
    ("nLostPacket", c_uint),
    ("nReserved", c_uint * 39),
]
MV_FRAME_OUT_INFO_EX = _MV_FRAME_OUT_INFO_EX_


# CameraParams.h 176
class _MV_DISPLAY_FRAME_INFO_(Structure):
    pass


_MV_DISPLAY_FRAME_INFO_._fields_ = [
    # CameraParams.h 176
    ("hWnd", c_void_p),
    ("pData", POINTER(c_ubyte)),
    ("nDataLen", c_uint),
    ("nWidth", c_ushort),
    ("nHeight", c_ushort),
    ("enPixelType", MvGvspPixelType),
    ("nRes", c_uint * 4),
]
MV_DISPLAY_FRAME_INFO = _MV_DISPLAY_FRAME_INFO_

# values for enumeration 'MV_SAVE_IAMGE_TYPE'
MV_SAVE_IAMGE_TYPE = c_int  # enum


# CameraParams.h 198
class _MV_SAVE_IMAGE_PARAM_T_(Structure):
    pass


_MV_SAVE_IMAGE_PARAM_T_._fields_ = [
    # CameraParams.h 198
    ("pData", POINTER(c_ubyte)),
    ("nDataLen", c_uint),
    ("enPixelType", MvGvspPixelType),
    ("nWidth", c_ushort),
    ("nHeight", c_ushort),
    ("pImageBuffer", POINTER(c_ubyte)),
    ("nImageLen", c_uint),
    ("nBufferSize", c_uint),
    ("enImageType", MV_SAVE_IAMGE_TYPE),
]
MV_SAVE_IMAGE_PARAM = _MV_SAVE_IMAGE_PARAM_T_


# CameraParams.h 214
class _MV_SAVE_IMAGE_PARAM_T_EX_(Structure):
    pass


_MV_SAVE_IMAGE_PARAM_T_EX_._fields_ = [
    # CameraParams.h 214
    ("pData", POINTER(c_ubyte)),
    ("nDataLen", c_uint),
    ("enPixelType", MvGvspPixelType),
    ("nWidth", c_ushort),
    ("nHeight", c_ushort),
    ("pImageBuffer", POINTER(c_ubyte)),
    ("nImageLen", c_uint),
    ("nBufferSize", c_uint),
    ("enImageType", MV_SAVE_IAMGE_TYPE),
    ("nJpgQuality", c_uint),
    ("iMethodValue", c_uint),
    ("nReserved", c_uint * 3),
]
MV_SAVE_IMAGE_PARAM_EX = _MV_SAVE_IMAGE_PARAM_T_EX_


# CameraParams.h 236
class _MV_PIXEL_CONVERT_PARAM_T_(Structure):
    pass


_MV_PIXEL_CONVERT_PARAM_T_._fields_ = [
    # CameraParams.h 236
    ("nWidth", c_ushort),
    ("nHeight", c_ushort),
    ("enSrcPixelType", MvGvspPixelType),
    ("pSrcData", POINTER(c_ubyte)),
    ("nSrcDataLen", c_uint),
    ("enDstPixelType", MvGvspPixelType),
    ("pDstBuffer", POINTER(c_ubyte)),
    ("nDstLen", c_uint),
    ("nDstBufferSize", c_uint),
    ("nRes", c_uint * 4),
]
MV_CC_PIXEL_CONVERT_PARAM = _MV_PIXEL_CONVERT_PARAM_T_

# values for enumeration '_MV_CAM_ACQUISITION_MODE_'
_MV_CAM_ACQUISITION_MODE_ = c_int  # enum
MV_CAM_ACQUISITION_MODE = _MV_CAM_ACQUISITION_MODE_

# values for enumeration '_MV_CAM_GAIN_MODE_'
_MV_CAM_GAIN_MODE_ = c_int  # enum
MV_CAM_GAIN_MODE = _MV_CAM_GAIN_MODE_

# values for enumeration '_MV_CAM_EXPOSURE_MODE_'
_MV_CAM_EXPOSURE_MODE_ = c_int  # enum
MV_CAM_EXPOSURE_MODE = _MV_CAM_EXPOSURE_MODE_

# values for enumeration '_MV_CAM_EXPOSURE_AUTO_MODE_'
_MV_CAM_EXPOSURE_AUTO_MODE_ = c_int  # enum
MV_CAM_EXPOSURE_AUTO_MODE = _MV_CAM_EXPOSURE_AUTO_MODE_

# values for enumeration '_MV_CAM_TRIGGER_MODE_'
_MV_CAM_TRIGGER_MODE_ = c_int  # enum
MV_CAM_TRIGGER_MODE = _MV_CAM_TRIGGER_MODE_

# values for enumeration '_MV_CAM_GAMMA_SELECTOR_'
_MV_CAM_GAMMA_SELECTOR_ = c_int  # enum
MV_CAM_GAMMA_SELECTOR = _MV_CAM_GAMMA_SELECTOR_

# values for enumeration '_MV_CAM_BALANCEWHITE_AUTO_'
_MV_CAM_BALANCEWHITE_AUTO_ = c_int  # enum
MV_CAM_BALANCEWHITE_AUTO = _MV_CAM_BALANCEWHITE_AUTO_

# values for enumeration '_MV_CAM_TRIGGER_SOURCE_'
_MV_CAM_TRIGGER_SOURCE_ = c_int  # enum
MV_CAM_TRIGGER_SOURCE = _MV_CAM_TRIGGER_SOURCE_

# values for enumeration '_MV_GIGE_TRANSMISSION_TYPE_'
_MV_GIGE_TRANSMISSION_TYPE_ = c_int  # enum
MV_GIGE_TRANSMISSION_TYPE = _MV_GIGE_TRANSMISSION_TYPE_


# CameraParams.h 377
class _MV_ALL_MATCH_INFO_(Structure):
    pass


_MV_ALL_MATCH_INFO_._fields_ = [
    # CameraParams.h 377
    ("nType", c_uint),
    ("pInfo", c_void_p),
    ("nInfoSize", c_uint),
]
MV_ALL_MATCH_INFO = _MV_ALL_MATCH_INFO_


# CameraParams.h 387
class _MV_MATCH_INFO_NET_DETECT_(Structure):
    pass


_MV_MATCH_INFO_NET_DETECT_._fields_ = [
    # CameraParams.h 387
    ("nReviceDataSize", int64_t),
    ("nLostPacketCount", int64_t),
    ("nLostFrameCount", c_uint),
    ("nReserved", c_uint * 5),
]
MV_MATCH_INFO_NET_DETECT = _MV_MATCH_INFO_NET_DETECT_


# CameraParams.h 396
class _MV_MATCH_INFO_USB_DETECT_(Structure):
    pass


_MV_MATCH_INFO_USB_DETECT_._fields_ = [
    # CameraParams.h 396
    ("nReviceDataSize", int64_t),
    ("nRevicedFrameCount", c_uint),
    ("nErrorFrameCount", c_uint),
    ("nReserved", c_uint * 2),
]
MV_MATCH_INFO_USB_DETECT = _MV_MATCH_INFO_USB_DETECT_


# CameraParams.h 404
class _MV_IMAGE_BASIC_INFO_(Structure):
    pass


_MV_IMAGE_BASIC_INFO_._fields_ = [
    # CameraParams.h 404
    ("nWidthValue", c_ushort),
    ("nWidthMin", c_ushort),
    ("nWidthMax", c_uint),
    ("nWidthInc", c_uint),
    ("nHeightValue", c_uint),
    ("nHeightMin", c_uint),
    ("nHeightMax", c_uint),
    ("nHeightInc", c_uint),
    ("fFrameRateValue", c_float),
    ("fFrameRateMin", c_float),
    ("fFrameRateMax", c_float),
    ("enPixelType", c_uint),
    ("nSupportedPixelFmtNum", c_uint),
    ("enPixelList", c_uint * 64),
    ("nReserved", c_uint * 8),
]
MV_IMAGE_BASIC_INFO = _MV_IMAGE_BASIC_INFO_

# values for enumeration 'MV_XML_InterfaceType'
MV_XML_InterfaceType = c_int  # enum

# values for enumeration 'MV_XML_AccessMode'
MV_XML_AccessMode = c_int  # enum

# values for enumeration 'MV_XML_Visibility'
MV_XML_Visibility = c_int  # enum


# CameraParams.h 500
class _MV_EVENT_OUT_INFO_(Structure):
    pass


_MV_EVENT_OUT_INFO_._fields_ = [
    # CameraParams.h 500
    ("EventName", c_char * 128),
    ("nEventID", c_ushort),
    ("nStreamChannel", c_ushort),
    ("nBlockIdHigh", c_uint),
    ("nBlockIdLow", c_uint),
    ("nTimestampHigh", c_uint),
    ("nTimestampLow", c_uint),
    ("pEventData", c_void_p),
    ("nEventDataSize", c_uint),
    ("nReserved", c_uint * 16),
]
MV_EVENT_OUT_INFO = _MV_EVENT_OUT_INFO_


# CameraParams.h 520
class _MV_CC_FILE_ACCESS_T(Structure):
    pass


_MV_CC_FILE_ACCESS_T._fields_ = [
    # CameraParams.h 520
    ("pUserFileName", STRING),
    ("pDevFileName", STRING),
    ("nReserved", c_uint * 32),
]
MV_CC_FILE_ACCESS = _MV_CC_FILE_ACCESS_T


# CameraParams.h 529
class _MV_CC_FILE_ACCESS_PROGRESS_T(Structure):
    pass


_MV_CC_FILE_ACCESS_PROGRESS_T._fields_ = [
    # CameraParams.h 529
    ("nCompleted", int64_t),
    ("nTotal", int64_t),
    ("nReserved", c_uint * 8),
]
MV_CC_FILE_ACCESS_PROGRESS = _MV_CC_FILE_ACCESS_PROGRESS_T


# CameraParams.h 538
class _MV_TRANSMISSION_TYPE_T(Structure):
    pass


_MV_TRANSMISSION_TYPE_T._fields_ = [
    # CameraParams.h 538
    ("enTransmissionType", MV_GIGE_TRANSMISSION_TYPE),
    ("nDestIp", c_uint),
    ("nDestPort", c_ushort),
    ("nReserved", c_uint * 32),
]
MV_TRANSMISSION_TYPE = _MV_TRANSMISSION_TYPE_T


# CameraParams.h 548
class _MV_XML_NODE_FEATURE_(Structure):
    pass


_MV_XML_NODE_FEATURE_._fields_ = [
    # CameraParams.h 548
    ("enType", MV_XML_InterfaceType),
    ("enVisivility", MV_XML_Visibility),
    ("strDescription", c_char * 512),
    ("strDisplayName", c_char * 64),
    ("strName", c_char * 64),
    ("strToolTip", c_char * 512),
    ("nReserved", c_uint * 4),
]
MV_XML_NODE_FEATURE = _MV_XML_NODE_FEATURE_


# CameraParams.h 561
class _MV_XML_NODES_LIST_(Structure):
    pass


_MV_XML_NODES_LIST_._fields_ = [
    # CameraParams.h 561
    ("nNodeNum", c_uint),
    ("stNodes", MV_XML_NODE_FEATURE * 128),
]
MV_XML_NODES_LIST = _MV_XML_NODES_LIST_


# CameraParams.h 569
class _MV_XML_FEATURE_Value_(Structure):
    pass


_MV_XML_FEATURE_Value_._fields_ = [
    # CameraParams.h 569
    ("enType", MV_XML_InterfaceType),
    ("strDescription", c_char * 512),
    ("strDisplayName", c_char * 64),
    ("strName", c_char * 64),
    ("strToolTip", c_char * 512),
    ("nReserved", c_uint * 4),
]
MV_XML_FEATURE_Value = _MV_XML_FEATURE_Value_


# CameraParams.h 579
class _MV_XML_FEATURE_Base_(Structure):
    pass


_MV_XML_FEATURE_Base_._fields_ = [
    # CameraParams.h 579
    ("enAccessMode", MV_XML_AccessMode),
]
MV_XML_FEATURE_Base = _MV_XML_FEATURE_Base_


# CameraParams.h 584
class _MV_XML_FEATURE_Integer_(Structure):
    pass


_MV_XML_FEATURE_Integer_._fields_ = [
    # CameraParams.h 584
    ("strName", c_char * 64),
    ("strDisplayName", c_char * 64),
    ("strDescription", c_char * 512),
    ("strToolTip", c_char * 512),
    ("enVisivility", MV_XML_Visibility),
    ("enAccessMode", MV_XML_AccessMode),
    ("bIsLocked", c_int),
    ("nValue", int64_t),
    ("nMinValue", int64_t),
    ("nMaxValue", int64_t),
    ("nIncrement", int64_t),
    ("nReserved", c_uint * 4),
]
MV_XML_FEATURE_Integer = _MV_XML_FEATURE_Integer_


# CameraParams.h 603
class _MV_XML_FEATURE_Boolean_(Structure):
    pass


_MV_XML_FEATURE_Boolean_._fields_ = [
    # CameraParams.h 603
    ("strName", c_char * 64),
    ("strDisplayName", c_char * 64),
    ("strDescription", c_char * 512),
    ("strToolTip", c_char * 512),
    ("enVisivility", MV_XML_Visibility),
    ("enAccessMode", MV_XML_AccessMode),
    ("bIsLocked", c_int),
    ("bValue", c_bool),
    ("nReserved", c_uint * 4),
]
MV_XML_FEATURE_Boolean = _MV_XML_FEATURE_Boolean_


# CameraParams.h 618
class _MV_XML_FEATURE_Command_(Structure):
    pass


_MV_XML_FEATURE_Command_._fields_ = [
    # CameraParams.h 618
    ("strName", c_char * 64),
    ("strDisplayName", c_char * 64),
    ("strDescription", c_char * 512),
    ("strToolTip", c_char * 512),
    ("enVisivility", MV_XML_Visibility),
    ("enAccessMode", MV_XML_AccessMode),
    ("bIsLocked", c_int),
    ("nReserved", c_uint * 4),
]
MV_XML_FEATURE_Command = _MV_XML_FEATURE_Command_


# CameraParams.h 632
class _MV_XML_FEATURE_Float_(Structure):
    pass


_MV_XML_FEATURE_Float_._fields_ = [
    # CameraParams.h 632
    ("strName", c_char * 64),
    ("strDisplayName", c_char * 64),
    ("strDescription", c_char * 512),
    ("strToolTip", c_char * 512),
    ("enVisivility", MV_XML_Visibility),
    ("enAccessMode", MV_XML_AccessMode),
    ("bIsLocked", c_int),
    ("dfValue", c_double),
    ("dfMinValue", c_double),
    ("dfMaxValue", c_double),
    ("dfIncrement", c_double),
    ("nReserved", c_uint * 4),
]
MV_XML_FEATURE_Float = _MV_XML_FEATURE_Float_


# CameraParams.h 650
class _MV_XML_FEATURE_String_(Structure):
    pass


_MV_XML_FEATURE_String_._fields_ = [
    # CameraParams.h 650
    ("strName", c_char * 64),
    ("strDisplayName", c_char * 64),
    ("strDescription", c_char * 512),
    ("strToolTip", c_char * 512),
    ("enVisivility", MV_XML_Visibility),
    ("enAccessMode", MV_XML_AccessMode),
    ("bIsLocked", c_int),
    ("strValue", c_char * 64),
    ("nReserved", c_uint * 4),
]
MV_XML_FEATURE_String = _MV_XML_FEATURE_String_


# CameraParams.h 665
class _MV_XML_FEATURE_Register_(Structure):
    pass


_MV_XML_FEATURE_Register_._fields_ = [
    # CameraParams.h 665
    ("strName", c_char * 64),
    ("strDisplayName", c_char * 64),
    ("strDescription", c_char * 512),
    ("strToolTip", c_char * 512),
    ("enVisivility", MV_XML_Visibility),
    ("enAccessMode", MV_XML_AccessMode),
    ("bIsLocked", c_int),
    ("nAddrValue", int64_t),
    ("nReserved", c_uint * 4),
]
MV_XML_FEATURE_Register = _MV_XML_FEATURE_Register_


# CameraParams.h 680
class _MV_XML_FEATURE_Category_(Structure):
    pass


_MV_XML_FEATURE_Category_._fields_ = [
    # CameraParams.h 680
    ("strDescription", c_char * 512),
    ("strDisplayName", c_char * 64),
    ("strName", c_char * 64),
    ("strToolTip", c_char * 512),
    ("enVisivility", MV_XML_Visibility),
    ("nReserved", c_uint * 4),
]
MV_XML_FEATURE_Category = _MV_XML_FEATURE_Category_


# CameraParams.h 692
class _MV_XML_FEATURE_EnumEntry_(Structure):
    pass


_MV_XML_FEATURE_EnumEntry_._fields_ = [
    # CameraParams.h 692
    ("strName", c_char * 64),
    ("strDisplayName", c_char * 64),
    ("strDescription", c_char * 512),
    ("strToolTip", c_char * 512),
    ("bIsImplemented", c_int),
    ("nParentsNum", c_int),
    ("stParentsList", MV_XML_NODE_FEATURE * 8),
    ("enVisivility", MV_XML_Visibility),
    ("nValue", int64_t),
    ("enAccessMode", MV_XML_AccessMode),
    ("bIsLocked", c_int),
    ("nReserved", c_int * 8),
]
MV_XML_FEATURE_EnumEntry = _MV_XML_FEATURE_EnumEntry_


# CameraParams.h 711
class _MV_XML_FEATURE_Enumeration_(Structure):
    pass


_MV_XML_FEATURE_Enumeration_._fields_ = [
    # CameraParams.h 711
    ("enVisivility", MV_XML_Visibility),
    ("strDescription", c_char * 512),
    ("strDisplayName", c_char * 64),
    ("strName", c_char * 64),
    ("strToolTip", c_char * 512),
    ("nSymbolicNum", c_int),
    ("strCurrentSymbolic", c_char * 64),
    ("strSymbolic", c_char * 64 * 64),
    ("enAccessMode", MV_XML_AccessMode),
    ("bIsLocked", c_int),
    ("nValue", int64_t),
    ("nReserved", c_uint * 4),
]
MV_XML_FEATURE_Enumeration = _MV_XML_FEATURE_Enumeration_


# CameraParams.h 730
class _MV_XML_FEATURE_Port_(Structure):
    pass


_MV_XML_FEATURE_Port_._fields_ = [
    # CameraParams.h 730
    ("enVisivility", MV_XML_Visibility),
    ("strDescription", c_char * 512),
    ("strDisplayName", c_char * 64),
    ("strName", c_char * 64),
    ("strToolTip", c_char * 512),
    ("enAccessMode", MV_XML_AccessMode),
    ("bIsLocked", c_int),
    ("nReserved", c_uint * 4),
]
MV_XML_FEATURE_Port = _MV_XML_FEATURE_Port_


# CameraParams.h 746
class _MV_XML_CAMERA_FEATURE_(Structure):
    pass


# CameraParams.h 749
class N23_MV_XML_CAMERA_FEATURE_3DOT_1E(Union):
    pass


N23_MV_XML_CAMERA_FEATURE_3DOT_1E._fields_ = [
    # CameraParams.h 749
    ("stIntegerFeature", MV_XML_FEATURE_Integer),
    ("stFloatFeature", MV_XML_FEATURE_Float),
    ("stEnumerationFeature", MV_XML_FEATURE_Enumeration),
    ("stStringFeature", MV_XML_FEATURE_String),
]
_MV_XML_CAMERA_FEATURE_._fields_ = [
    # CameraParams.h 746
    ("enType", MV_XML_InterfaceType),
    ("SpecialFeature", N23_MV_XML_CAMERA_FEATURE_3DOT_1E),
]
MV_XML_CAMERA_FEATURE = _MV_XML_CAMERA_FEATURE_


# CameraParams.h 760
class _MVCC_ENUMVALUE_T(Structure):
    pass


_MVCC_ENUMVALUE_T._fields_ = [
    # CameraParams.h 760
    ("nCurValue", c_uint),
    ("nSupportedNum", c_uint),
    ("nSupportValue", c_uint * 64),
    ("nReserved", c_uint * 4),
]
MVCC_ENUMVALUE = _MVCC_ENUMVALUE_T


# CameraParams.h 769
class _MVCC_INTVALUE_T(Structure):
    pass


_MVCC_INTVALUE_T._fields_ = [
    # CameraParams.h 769
    ("nCurValue", c_uint),
    ("nMax", c_uint),
    ("nMin", c_uint),
    ("nInc", c_uint),
    ("nReserved", c_uint * 4),
]
MVCC_INTVALUE = _MVCC_INTVALUE_T


# CameraParams.h 779
class _MVCC_INTVALUE_EX_T(Structure):
    pass


_MVCC_INTVALUE_EX_T._fields_ = [
    # CameraParams.h 779
    ("nCurValue", int64_t),
    ("nMax", int64_t),
    ("nMin", int64_t),
    ("nInc", int64_t),
    ("nReserved", c_uint * 16),
]
MVCC_INTVALUE_EX = _MVCC_INTVALUE_EX_T


# CameraParams.h 789
class _MVCC_FLOATVALUE_T(Structure):
    pass


_MVCC_FLOATVALUE_T._fields_ = [
    # CameraParams.h 789
    ("fCurValue", c_float),
    ("fMax", c_float),
    ("fMin", c_float),
    ("nReserved", c_uint * 4),
]
MVCC_FLOATVALUE = _MVCC_FLOATVALUE_T


# CameraParams.h 798
class _MVCC_STRINGVALUE_T(Structure):
    pass


_MVCC_STRINGVALUE_T._fields_ = [
    # CameraParams.h 798
    ("chCurValue", c_char * 256),
    ("nMaxLength", int64_t),
    ("nReserved", c_uint * 2),
]
MVCC_STRINGVALUE = _MVCC_STRINGVALUE_T
__all__ = [
    "_MV_ALL_MATCH_INFO_",
    "_MV_XML_FEATURE_Integer_",
    "MV_CC_FILE_ACCESS_PROGRESS",
    "N19_MV_CC_DEVICE_INFO_3DOT_0E",
    "MV_CAM_EXPOSURE_AUTO_MODE",
    "PixelType_Gvsp_BayerRG8",
    "MV_CAM_GAIN_MODE",
    "MV_GIGE_TRANSTYPE_UNICAST_WITHOUT_RECV",
    "PixelType_Gvsp_BayerGB12_Packed",
    "MV_TRIGGER_SOURCE_LINE0",
    "MV_TRIGGER_SOURCE_LINE1",
    "MV_TRIGGER_SOURCE_LINE2",
    "MV_TRIGGER_SOURCE_LINE3",
    "AM_CycleDetect",
    "PixelType_Gvsp_YCBCR422_8",
    "IFT_IFloat",
    "MV_TRANSMISSION_TYPE",
    "_MV_XML_FEATURE_Command_",
    "_MV_XML_FEATURE_String_",
    "_MV_CAM_TRIGGER_SOURCE_",
    "PixelType_Gvsp_COORD3D_DEPTH_PLUS_MASK",
    "PixelType_Gvsp_RGB10V1_Packed",
    "PixelType_Gvsp_RGB10_Packed",
    "PixelType_Gvsp_RGB8_Planar",
    "AM_RO",
    "IFT_IPort",
    "uint_least16_t",
    "_MV_FRAME_OUT_INFO_EX_",
    "_MV_TRANSMISSION_TYPE_T",
    "MV_SAVE_IMAGE_PARAM_EX",
    "AM_RW",
    "MV_XML_InterfaceType",
    "_MV_XML_CAMERA_FEATURE_",
    "intptr_t",
    "uint_least64_t",
    "V_Guru",
    "_MV_CAM_TRIGGER_MODE_",
    "MV_CAM_EXPOSURE_MODE",
    "int_least32_t",
    "MV_GIGE_TRANSTYPE_SUBNETBROADCAST",
    "_MV_XML_FEATURE_Boolean_",
    "MV_BALANCEWHITE_AUTO_CONTINUOUS",
    "MV_XML_NODE_FEATURE",
    "_MV_FRAME_OUT_INFO_",
    "MV_ALL_MATCH_INFO",
    "_MV_XML_FEATURE_EnumEntry_",
    "_MV_PIXEL_CONVERT_PARAM_T_",
    "PixelType_Gvsp_RGB16_Packed",
    "PixelType_Gvsp_RGBA8_Packed",
    "PixelType_Gvsp_RGB8_Packed",
    "MV_ACQ_MODE_SINGLE",
    "MV_TRIGGER_MODE_ON",
    "_MV_XML_FEATURE_Base_",
    "PixelType_Gvsp_Mono8_Signed",
    "int_least16_t",
    "MV_GIGE_TRANSTYPE_LIMITEDBROADCAST",
    "int_fast32_t",
    "_MV_CAM_GAIN_MODE_",
    "uint_fast16_t",
    "_MV_DISPLAY_FRAME_INFO_",
    "IFT_ICommand",
    "PixelType_Gvsp_BayerBG10_Packed",
    "_MV_CAM_ACQUISITION_MODE_",
    "PixelType_Gvsp_YCBCR709_422_8_CBYCRY",
    "V_Beginner",
    "PixelType_Gvsp_BayerBG16",
    "MV_GIGE_TRANSTYPE_MULTICAST_WITHOUT_RECV",
    "MVCC_INTVALUE",
    "_MV_XML_FEATURE_Port_",
    "_MV_GIGE_TRANSMISSION_TYPE_",
    "MV_GIGE_TRANSMISSION_TYPE",
    "PixelType_Gvsp_YUV411_Packed",
    "_MV_XML_FEATURE_Register_",
    "MV_EXPOSURE_MODE_TIMED",
    "intmax_t",
    "PixelType_Gvsp_BayerBG12_Packed",
    "int16_t",
    "MV_DISPLAY_FRAME_INFO",
    "MV_XML_FEATURE_Integer",
    "_MV_CC_FILE_ACCESS_PROGRESS_T",
    "MV_XML_Visibility",
    "IFT_IEnumEntry",
    "int_fast64_t",
    "PixelType_Gvsp_BayerRG12",
    "PixelType_Gvsp_BayerRG10",
    "MV_XML_AccessMode",
    "V_Expert",
    "MV_GAIN_MODE_ONCE",
    "IFT_IInteger",
    "PixelType_Gvsp_YCBCR709_411_8_CBYYCRYY",
    "MV_CAM_BALANCEWHITE_AUTO",
    "int_least8_t",
    "IFT_IBase",
    "MV_XML_NODES_LIST",
    "MV_TRIGGER_MODE_OFF",
    "MV_Image_Bmp",
    "MV_XML_FEATURE_String",
    "MV_CC_FILE_ACCESS",
    "_MV_CAM_EXPOSURE_AUTO_MODE_",
    "PixelType_Gvsp_Coord3D_AC32f",
    "uint_least8_t",
    "PixelType_Gvsp_BayerRG12_Packed",
    "_MV_XML_FEATURE_Float_",
    "_MV_XML_NODE_FEATURE_",
    "MV_XML_FEATURE_Float",
    "PixelType_Gvsp_BGR12_Packed",
    "PixelType_Gvsp_YUV422_Packed",
    "MV_SAVE_IMAGE_PARAM",
    "MV_EVENT_OUT_INFO",
    "IFT_IEnumeration",
    "uint64_t",
    "uint8_t",
    "PixelType_Gvsp_RGB12_Planar",
    "V_Undefined",
    "_MVCC_STRINGVALUE_T",
    "PixelType_Gvsp_YCBCR709_422_8",
    "MV_CAM_TRIGGER_MODE",
    "PixelType_Gvsp_BayerRG10_Packed",
    "N23_MV_XML_CAMERA_FEATURE_3DOT_1E",
    "uint16_t",
    "uint_fast8_t",
    "_MV_SAVE_IMAGE_PARAM_T_",
    "PixelType_Gvsp_BGR8_Packed",
    "_MVCC_ENUMVALUE_T",
    "_MV_MATCH_INFO_USB_DETECT_",
    "MV_XML_FEATURE_Category",
    "PixelType_Gvsp_Jpeg",
    "int32_t",
    "PixelType_Gvsp_BayerGR10_Packed",
    "MV_XML_FEATURE_EnumEntry",
    "_MV_CC_DEVICE_INFO_",
    "PixelType_Gvsp_BayerBG12",
    "PixelType_Gvsp_BayerBG10",
    "IFT_IBoolean",
    "PixelType_Gvsp_Mono12",
    "MV_MATCH_INFO_USB_DETECT",
    "PixelType_Gvsp_RGB16_Planar",
    "MVCC_ENUMVALUE",
    "IFT_IString",
    "PixelType_Gvsp_BayerRG16",
    "_MV_XML_FEATURE_Value_",
    "MV_ACQ_MODE_CONTINUOUS",
    "MV_TRIGGER_SOURCE_FrequencyConverter",
    "PixelType_Gvsp_Mono4p",
    "MV_TRIGGER_SOURCE_COUNTER0",
    "MV_GAIN_MODE_OFF",
    "MV_Image_Png",
    "_MV_CC_DEVICE_INFO_LIST_",
    "MV_GIGE_DEVICE_INFO",
    "_MV_SAVE_IMAGE_PARAM_T_EX_",
    "PixelType_Gvsp_Mono8",
    "uint_least32_t",
    "PixelType_Gvsp_BayerGR16",
    "MV_FRAME_OUT_INFO",
    "PixelType_Gvsp_BayerGR10",
    "PixelType_Gvsp_BGRA8_Packed",
    "PixelType_Gvsp_BayerGR12",
    "_MVCC_INTVALUE_EX_T",
    "uintptr_t",
    "PixelType_Gvsp_Mono12_Packed",
    "MVCC_FLOATVALUE",
    "MV_GIGE_TRANSTYPE_CAMERADEFINED",
    "_MV_XML_NODES_LIST_",
    "MV_NETTRANS_INFO",
    "IFT_IRegister",
    "AM_NA",
    "MV_GIGE_TRANSTYPE_UNICAST",
    "int8_t",
    "_MV_GIGE_DEVICE_INFO_",
    "IFT_IValue",
    "IFT_ICategory",
    "int_fast8_t",
    "PixelType_Gvsp_YCBCR709_8_CBYCR",
    "MV_XML_FEATURE_Enumeration",
    "MV_GAMMA_SELECTOR_SRGB",
    "PixelType_Gvsp_YCBCR601_422_8",
    "PixelType_Gvsp_YCBCR411_8_CBYYCRYY",
    "int_least64_t",
    "MV_EXPOSURE_AUTO_MODE_OFF",
    "MV_CC_PIXEL_CONVERT_PARAM",
    "MV_EXPOSURE_AUTO_MODE_CONTINUOUS",
    "MV_CAM_ACQUISITION_MODE",
    "_MVCC_INTVALUE_T",
    "MV_XML_FEATURE_Value",
    "AM_Undefined",
    "MV_MATCH_INFO_NET_DETECT",
    "PixelType_Gvsp_Undefined",
    "_MV_CC_FILE_ACCESS_T",
    "AM_NI",
    "PixelType_Gvsp_BayerGR12_Packed",
    "V_Invisible",
    "PixelType_Gvsp_YCBCR601_411_8_CBYYCRYY",
    "PixelType_Gvsp_RGB10_Planar",
    "MV_CAM_GAMMA_SELECTOR",
    "MV_TRIGGER_SOURCE_SOFTWARE",
    "PixelType_Gvsp_BayerGB16",
    "MV_BALANCEWHITE_AUTO_ONCE",
    "PixelType_Gvsp_BayerGB10",
    "uintmax_t",
    "PixelType_Gvsp_BayerGB12",
    "int_fast16_t",
    "_MV_CAM_EXPOSURE_MODE_",
    "MV_Image_Tif",
    "PixelType_Gvsp_BGR565_Packed",
    "MV_BALANCEWHITE_AUTO_OFF",
    "int64_t",
    "MV_Image_Undefined",
    "_MV_NETTRANS_INFO_",
    "MV_GAIN_MODE_CONTINUOUS",
    "PixelType_Gvsp_Mono1p",
    "uint_fast32_t",
    "MV_CAM_TRIGGER_SOURCE",
    "PixelType_Gvsp_YUV444_Packed",
    "MV_Image_Jpeg",
    "_MVCC_FLOATVALUE_T",
    "MV_XML_FEATURE_Port",
    "PixelType_Gvsp_YUV422_YUYV_Packed",
    "MV_FRAME_OUT_INFO_EX",
    "_MV_IMAGE_BASIC_INFO_",
    "_MV_CAM_BALANCEWHITE_AUTO_",
    "MV_XML_FEATURE_Base",
    "_MV_USB3_DEVICE_INFO_",
    "PixelType_Gvsp_BayerBG8",
    "MVCC_INTVALUE_EX",
    "MV_XML_FEATURE_Register",
    "AM_WO",
    "MV_GIGE_TRANSTYPE_UNICAST_DEFINED_PORT",
    "_MV_XML_FEATURE_Enumeration_",
    "_MV_MATCH_INFO_NET_DETECT_",
    "MV_SAVE_IAMGE_TYPE",
    "MV_EXPOSURE_AUTO_MODE_ONCE",
    "PixelType_Gvsp_BGR10_Packed",
    "PixelType_Gvsp_BayerGB10_Packed",
    "PixelType_Gvsp_Coord3D_ABC32f_Planar",
    "MV_GIGE_TRANSTYPE_MULTICAST",
    "MV_XML_CAMERA_FEATURE",
    "PixelType_Gvsp_Coord3D_ABC32f",
    "MVCC_STRINGVALUE",
    "MV_CC_DEVICE_INFO",
    "PixelType_Gvsp_YCBCR422_8_CBYCRY",
    "PixelType_Gvsp_RGB12_Packed",
    "PixelType_Gvsp_BayerGR8",
    "MvGvspPixelType",
    "PixelType_Gvsp_Mono10",
    "MV_IMAGE_BASIC_INFO",
    "PixelType_Gvsp_Mono16",
    "PixelType_Gvsp_Mono2p",
    "PixelType_Gvsp_Mono14",
    "PixelType_Gvsp_RGB10V2_Packed",
    "MV_CC_DEVICE_INFO_LIST",
    "PixelType_Gvsp_RGB12V1_Packed",
    "PixelType_Gvsp_Mono10_Packed",
    "uint_fast64_t",
    "PixelType_Gvsp_YCBCR601_8_CBYCR",
    "PixelType_Gvsp_BayerGB8",
    "_MV_XML_FEATURE_Category_",
    "MV_EXPOSURE_MODE_TRIGGER_WIDTH",
    "PixelType_Gvsp_YCBCR8_CBYCR",
    "MV_XML_FEATURE_Boolean",
    "MV_GAMMA_SELECTOR_USER",
    "PixelType_Gvsp_RGB565_Packed",
    "uint32_t",
    "MV_XML_FEATURE_Command",
    "_MV_CAM_GAMMA_SELECTOR_",
    "MV_ACQ_MODE_MUTLI",
    "PixelType_Gvsp_YCBCR601_422_8_CBYCRY",
    "MV_USB3_DEVICE_INFO",
    "_MV_EVENT_OUT_INFO_",
]
