# -*- coding: utf-8 -*-
# Don't change this file, it was auto generated by Const_file_Generater.py.
# pylint: skip-file

MV_UNKNOW_DEVICE = 0x00000000  # ch:未知设备类型，保留意义 | en:Unknown Device Type, Reserved
MV_GIGE_DEVICE = 0x00000001  # ch:GigE设备 | en:GigE Device
MV_1394_DEVICE = 0x00000002  # ch:1394-a/b 设备 | en:1394-a/b Device
MV_USB_DEVICE = 0x00000004  # ch:USB3.0 设备 | en:USB3.0 Device
MV_CAMERALINK_DEVICE = 0x00000008  # ch:CameraLink设备 | en:CameraLink Device
INFO_MAX_BUFFER_SIZE = 64
MV_MAX_TLS_NUM = 8
MV_MAX_DEVICE_NUM = 256
MV_IP_CFG_STATIC = 0x05000000
MV_IP_CFG_DHCP = 0x06000000
MV_IP_CFG_LLA = 0x04000000
MV_NET_TRANS_DRIVER = 0x00000001
MV_NET_TRANS_SOCKET = 0x00000002
MV_MATCH_TYPE_NET_DETECT = 0x00000001  # ch:网络流量和丢包信息 | en:Network traffic and packet loss information
MV_MATCH_TYPE_USB_DETECT = (
    0x00000002  # ch:host接收到来自U3V设备的字节总数 | en:The total number of bytes host received from U3V device
)
MV_MAX_XML_NODE_NUM_C = 128
MV_MAX_XML_NODE_STRLEN_C = 64
MV_MAX_XML_STRVALUE_STRLEN_C = 64
MV_MAX_XML_DISC_STRLEN_C = 512
MV_MAX_XML_ENTRY_NUM = 10
MV_MAX_XML_PARENTS_NUM = 8
MV_MAX_XML_SYMBOLIC_STRLEN_C = 64
MV_MAX_XML_SYMBOLIC_NUM = 64
MV_EXCEPTION_DEV_DISCONNECT = 0x00008001  # ch:设备断开连接 | en:The device is disconnected
MV_EXCEPTION_VERSION_CHECK = 0x00008002  # ch:SDK与驱动版本不匹配 | en:SDK does not match the driver version
MV_ACCESS_Exclusive = 1
MV_ACCESS_ExclusiveWithSwitch = 2
MV_ACCESS_Control = 3
MV_ACCESS_ControlWithSwitch = 4
MV_ACCESS_ControlSwitchEnable = 5
MV_ACCESS_ControlSwitchEnableWithKey = 6
MV_ACCESS_Monitor = 7
MAX_EVENT_NAME_SIZE = 128  # 相机Event事件名称最大长度 | en:Max length of event name
