# -*- coding: utf-8 -*-
# Don't change this file, it was auto generated by Const_file_Generater.py.
# pylint: skip-file

MV_GVSP_PIX_MONO = 0x01000000
MV_GVSP_PIX_RGB = 0x02000000  # deprecated in version 1.1
MV_GVSP_PIX_COLOR = 0x02000000
MV_GVSP_PIX_CUSTOM = 0x80000000
MV_GVSP_PIX_COLOR_MASK = 0xFF000000
MV_GVSP_PIX_EFFECTIVE_PIXEL_SIZE_MASK = 0x00FF0000
MV_GVSP_PIX_EFFECTIVE_PIXEL_SIZE_SHIFT = 16
MV_GVSP_PIX_ID_MASK = 0x0000FFFF
MV_GVSP_PIX_COUNT = 0x46  # next Pixel ID available
